import refractfs

import pkg_resources
packages = pkg_resources.working_set
packages_list = ["%s==%s" % (i.key, i.version) for i in packages]

if 'refractfs==1.0.0' in packages_list:
    print("There is my boy")
else:
    print("Where is my boy??")
# print(packages_list)


#! /usr/bin/env python
# -*- coding: utf-8 -*-
import os
import tempfile

from constants import Flavour
from mosaic_utils.ai.file_utils import extract_tar
from mosaic_utils.ai.flavours import (
    keras,
    pytorch,
    sklearn,
    tensorflow,
    pyspark,
    spacy,
    pmml,
    xgboost,
)


def download_model(model_tar_path):
    """download model artifacts from object storage server"""
    # download model from object storage server
    # model_data = get_model_data(model_tar_path)
    # write model to tar file
    temp_dir = tempfile.mkdtemp()

    tar_path = os.path.join(model_tar_path, "ml_model.tar.gz")
    # model_data.save(tar_path)
    # extract model file
    extract_tar(tar_path, temp_dir)

    # Getting the list of directories
    dir = os.listdir(temp_dir)
    # Checking if the list is empty or not
    if len(dir) != 0:
        return temp_dir


def get_loader(flavour):
    if flavour == Flavour.keras:
        return keras.load_model
    if flavour == Flavour.sklearn:
        return sklearn.load_model
    if flavour == Flavour.pytorch:
        return pytorch.load_model
    if flavour == Flavour.tensorflow:
        return tensorflow.load_model
    if flavour == Flavour.pyspark:
        return pyspark.load_model
    if flavour == Flavour.spacy:
        return spacy.load_model
    if flavour == Flavour.r:
        # R import specifically moved below as it will give error of rpy2 while deploying otherwise
        from mosaic_utils.ai.flavours import r

        return r.load_model
    if flavour == Flavour.pmml:
        return pmml.load_model
    if flavour == Flavour.xgboost:
        return xgboost.load_model



import os
import requests
import tempfile
from feast import FeatureStore
from datetime import datetime
from constants import CommonService


def main():
    import time
    print("The time of code execution begin is : ", time.ctime())
    # time.sleep()
    print("The time of code will begin now")

    frequency = os.getenv("frequency")
    print("frequency - ", frequency)

    store_name = "Test_snow_30_oct_2"
    url = CommonService.base_url + CommonService.feature_store.format(store_name)
    token = os.getenv("TOKEN")

    # headers = {
    #     "Authorization": 'token {}'.format(token)
    # }

    headers = {
        "accept": "application/json",
        "X-Project-Id": os.getenv("PROJECT_ID"),
        'X-Auth-Userid': os.getenv("userId"),
        'X-Auth-Username': os.getenv("userId"),
        'X-Auth-Email': os.getenv("userId"),
    }

    response = requests.get(url=url,
                            headers=headers,
                            verify=False)

    print("store_obj - ", response)
    temp_dir = tempfile.mkdtemp()

    yaml_path = os.path.join(temp_dir, "feature_store.yaml")

    if response.status_code == 200:
        # Parse the JSON response
        with open(yaml_path, 'wb') as f:
            f.write(response.content)

    store_materialize(temp_dir)

    # read env data
    # get token
    # call refract common service for fs object details
    # create fs object and yaml
    # run materialize command
    # get the result
    # store the result

    print("Inside feature store recipe code", frequency)

    return "OK"


def store_materialize(yaml_path):
    store = FeatureStore(repo_path=yaml_path)

    print(store.materialize_incremental(end_date=datetime.utcnow()))

    # print("materialize logs- ", materialize)
    return "OK"


if __name__ == "__main__":
    main()
